References
==========

.. [Unser1999] M\. Unser, “Splines: A perfect fit for signal and image processing,” IEEE Signal processing magazine, vol. 16, no. 6, pp. 22–38, 1999.

.. [Delgado2012] R\. Delgado-Gonzalo, P. Thévenaz, and M. Unser, “Exponential splines and minimal-support bases for curve representation,” Computer Aided Geometric Design, vol. 29, no. 2, pp. 109–128, 2012.

.. [Keys1981] R\. Keys, “Cubic convolution interpolation for digital image processing,” IEEE transactions on acoustics, speech, and signal processing, vol. 29, no. 6, pp. 1153–1160, 1981.

.. [Uhlmann2014] V\. Uhlmann, R. Delgado-Gonzalo, C. Conti, L. Romani, and M. Unser, “Exponential hermite splines for the analysis of biomedical images,” 2014 IEEE International Conference on Acoustics, Speech and Signal Processing (ICASSP). IEEE, 2014, pp. 1631–1634

.. [Uhlmann2016] V\. Uhlmann, J. Fageot, and M. Unser, “Hermite snakes with control of tangents,” IEEE Transactions on Image Processing, vol. 25, no. 6, pp. 2803–2816, 2016.

.. [Badoual2016] A\. Badoual, D. Schmitter, M. Unser, "Local Refinement for 3D Deformable Parametric Surfaces," Proceedings of the 2016 IEEE International Conference on Image Processing (ICIP'16). IEEE, 2016, pp. 1086-1090
